from setuptools import setup, find_packages

setup(
name='GPS-Package2',
version='0.1.0',
author='Ely Millán',
author_email='ely141117@gmail.com',
description='PyPi Upload of the GPS Project',
packages=find_packages(),
classifiers=[
'Programming Language :: Python :: 3',
'License :: OSI Approved :: MIT License',
'Operating System :: OS Independent',
],
python_requires='>=3.10',
)